==> jc-1.4.0.tar.gz: soot/baf/internal/BSpecialInvokeInst.h <==
// public class soot.baf.internal.BSpecialInvokeInst

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class 75a736fe6c448796 soot_baf_internal_AbstractInst
// @dep_class 9eae4bbac6711e7a soot_baf_internal_AbstractInvokeInst
// @dep_class 119d5ee90d75747d soot_baf_internal_BSpecialInvokeInst
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_baf_internal_AbstractInvokeInst

#include "soot/baf/internal/AbstractInvokeInst.h"

#ifndef _JC_soot_baf_internal_BSpecialInvokeInst_H_
#define _JC_soot_baf_internal_BSpecialInvokeInst_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_baf_internal_BSpecialInvokeInst$sub_refs	_jc_soot_baf_internal_BSpecialInvokeInst$sub_refs;
typedef struct _jc_soot_baf_internal_BSpecialInvokeInst$sub_nonrefs	_jc_soot_baf_internal_BSpecialInvokeInst$sub_nonrefs;
typedef struct _jc_soot_baf_internal_BSpecialInvokeInst$refs	_jc_soot_baf_internal_BSpecialInvokeInst$refs;
typedef struct _jc_soot_baf_internal_BSpecialInvokeInst$nonrefs	_jc_soot_baf_internal_BSpecialInvokeInst$nonrefs;
typedef struct _jc_soot_baf_internal_BSpecialInvokeInst$object	_jc_soot_baf_internal_BSpecialInvokeInst$object;

typedef const struct _jc_soot_baf_internal_BSpecialInvokeInst$vmethods	_jc_soot_baf_internal_BSpecialInvokeInst$vmethods;
typedef const struct _jc_soot_baf_internal_BSpecialInvokeInst$vtable	_jc_soot_baf_internal_BSpecialInvokeInst$vtable;
typedef const struct _jc_soot_baf_internal_BSpecialInvokeInst$vtype	_jc_soot_baf_internal_BSpecialInvokeInst$vtype;

// Constructors
extern void _jc_soot_baf_internal_BSpecialInvokeInst$method$_init$5ff894e1e168ec0b(_jc_env *, struct _jc_soot_baf_internal_BSpecialInvokeInst$object *, struct _jc_soot_SootMethod$object *);

// Virtual methods
extern void _jc_soot_baf_internal_BSpecialInvokeInst$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_baf_internal_BSpecialInvokeInst$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_baf_internal_BSpecialInvokeInst$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_baf_internal_BSpecialInvokeInst$object *);
extern jint _jc_soot_baf_internal_BSpecialInvokeInst$method$getInCount$56a53206ce41ebab(_jc_env *, struct _jc_soot_baf_internal_BSpecialInvokeInst$object *);
extern jint _jc_soot_baf_internal_BSpecialInvokeInst$method$getInMachineCount$53f8938c85f21ad5(_jc_env *, struct _jc_soot_baf_internal_BSpecialInvokeInst$object *);
extern struct _jc_java_lang_String$object *_jc_soot_baf_internal_BSpecialInvokeInst$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_baf_internal_BSpecialInvokeInst$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_baf_internal_BSpecialInvokeInst$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_baf_internal_BSpecialInvokeInst$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_baf_internal_BSpecialInvokeInst$method_info$getInCount$56a53206ce41ebab;
extern _jc_method _jc_soot_baf_internal_BSpecialInvokeInst$method_info$getInMachineCount$53f8938c85f21ad5;
extern _jc_method _jc_soot_baf_internal_BSpecialInvokeInst$method_info$getName$bec186f2ce7e1882;

// Virtual methods structure
struct _jc_soot_baf_internal_BSpecialInvokeInst$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_baf_internal_BSpecialInvokeInst$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_baf_internal_BSpecialInvokeInst$object *);
	jint	(*getInCount$56a53206ce41ebab)(_jc_env *, struct _jc_soot_baf_internal_BSpecialInvokeInst$object *);
	jint	(*getInMachineCount$53f8938c85f21ad5)(_jc_env *, struct _jc_soot_baf_internal_BSpecialInvokeInst$object *);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_baf_internal_BSpecialInvokeInst$object *);
};

// Vtable
struct _jc_soot_baf_internal_BSpecialInvokeInst$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_baf_internal_AbstractInst$vmethods	soot_baf_internal_AbstractInst;
	_jc_soot_baf_internal_AbstractInvokeInst$vmethods	soot_baf_internal_AbstractInvokeInst;
	_jc_soot_baf_internal_BSpecialInvokeInst$vmethods	soot_baf_internal_BSpecialInvokeInst;
};

// Vtype
struct _jc_soot_baf_internal_BSpecialInvokeInst$vtype {
	_jc_type			type;
	_jc_soot_baf_internal_BSpecialInvokeInst$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_baf_internal_BSpecialInvokeInst$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_baf_internal_BSpecialInvokeInst$refs {
    _jc_soot_baf_internal_BSpecialInvokeInst$sub_refs	soot_baf_internal_BSpecialInvokeInst;
    _jc_soot_baf_internal_AbstractInvokeInst$sub_refs	soot_baf_internal_AbstractInvokeInst;
    _jc_soot_baf_internal_AbstractInst$sub_refs	soot_baf_internal_AbstractInst;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_baf_internal_BSpecialInvokeInst$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_baf_internal_BSpecialInvokeInst$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_baf_internal_AbstractInst$sub_nonrefs	soot_baf_internal_AbstractInst;
    _jc_soot_baf_internal_AbstractInvokeInst$sub_nonrefs	soot_baf_internal_AbstractInvokeInst;
    _jc_soot_baf_internal_BSpecialInvokeInst$sub_nonrefs	soot_baf_internal_BSpecialInvokeInst;
};

// Object instance structure
struct _jc_soot_baf_internal_BSpecialInvokeInst$object {
	_jc_soot_baf_internal_BSpecialInvokeInst$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_baf_internal_BSpecialInvokeInst$vtype	*vtype;
	_jc_soot_baf_internal_BSpecialInvokeInst$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_baf_internal_BSpecialInvokeInst$vtype _jc_soot_baf_internal_BSpecialInvokeInst$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_baf_internal_BSpecialInvokeInst, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_baf_internal_BSpecialInvokeInst$class_object;

#endif	/* _JC_soot_baf_internal_BSpecialInvokeInst_H_ */

==> jc-1.4.6.tar.gz: soot/baf/internal/BSpecialInvokeInst.h <==
// public class soot.baf.internal.BSpecialInvokeInst

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class 75a736fe6c448796 soot_baf_internal_AbstractInst
// @dep_class 9eae4bbac6711e7a soot_baf_internal_AbstractInvokeInst
// @dep_class 119d5ee90d75747d soot_baf_internal_BSpecialInvokeInst
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_baf_internal_AbstractInvokeInst

#include "soot/baf/internal/AbstractInvokeInst.h"

#ifndef _JC_soot_baf_internal_BSpecialInvokeInst_H_
#define _JC_soot_baf_internal_BSpecialInvokeInst_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_baf_internal_BSpecialInvokeInst$sub_refs	_jc_soot_baf_internal_BSpecialInvokeInst$sub_refs;
typedef struct _jc_soot_baf_internal_BSpecialInvokeInst$sub_nonrefs	_jc_soot_baf_internal_BSpecialInvokeInst$sub_nonrefs;
typedef struct _jc_soot_baf_internal_BSpecialInvokeInst$refs	_jc_soot_baf_internal_BSpecialInvokeInst$refs;
typedef struct _jc_soot_baf_internal_BSpecialInvokeInst$nonrefs	_jc_soot_baf_internal_BSpecialInvokeInst$nonrefs;
typedef struct _jc_soot_baf_internal_BSpecialInvokeInst$object	_jc_soot_baf_internal_BSpecialInvokeInst$object;

typedef const struct _jc_soot_baf_internal_BSpecialInvokeInst$vmethods	_jc_soot_baf_internal_BSpecialInvokeInst$vmethods;
typedef const struct _jc_soot_baf_internal_BSpecialInvokeInst$vtable	_jc_soot_baf_internal_BSpecialInvokeInst$vtable;
typedef const struct _jc_soot_baf_internal_BSpecialInvokeInst$vtype	_jc_soot_baf_internal_BSpecialInvokeInst$vtype;

// Constructors
extern void _jc_soot_baf_internal_BSpecialInvokeInst$method$_init$5ff894e1e168ec0b(_jc_env *, struct _jc_soot_baf_internal_BSpecialInvokeInst$object *, struct _jc_soot_SootMethod$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_baf_internal_BSpecialInvokeInst$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_baf_internal_BSpecialInvokeInst$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_baf_internal_BSpecialInvokeInst$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_baf_internal_BSpecialInvokeInst$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_baf_internal_BSpecialInvokeInst$method$getInCount$56a53206ce41ebab(_jc_env *, struct _jc_soot_baf_internal_BSpecialInvokeInst$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_baf_internal_BSpecialInvokeInst$method$getInMachineCount$53f8938c85f21ad5(_jc_env *, struct _jc_soot_baf_internal_BSpecialInvokeInst$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_baf_internal_BSpecialInvokeInst$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_baf_internal_BSpecialInvokeInst$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_baf_internal_BSpecialInvokeInst$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_baf_internal_BSpecialInvokeInst$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_baf_internal_BSpecialInvokeInst$method_info$getInCount$56a53206ce41ebab;
extern _jc_method _jc_soot_baf_internal_BSpecialInvokeInst$method_info$getInMachineCount$53f8938c85f21ad5;
extern _jc_method _jc_soot_baf_internal_BSpecialInvokeInst$method_info$getName$bec186f2ce7e1882;

// Virtual methods structure
struct _jc_soot_baf_internal_BSpecialInvokeInst$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_baf_internal_BSpecialInvokeInst$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_baf_internal_BSpecialInvokeInst$object *) _JC_JCNI_ATTR;
	jint	(*getInCount$56a53206ce41ebab)(_jc_env *, struct _jc_soot_baf_internal_BSpecialInvokeInst$object *) _JC_JCNI_ATTR;
	jint	(*getInMachineCount$53f8938c85f21ad5)(_jc_env *, struct _jc_soot_baf_internal_BSpecialInvokeInst$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_baf_internal_BSpecialInvokeInst$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_baf_internal_BSpecialInvokeInst$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_baf_internal_AbstractInst$vmethods	soot_baf_internal_AbstractInst;
	_jc_soot_baf_internal_AbstractInvokeInst$vmethods	soot_baf_internal_AbstractInvokeInst;
	_jc_soot_baf_internal_BSpecialInvokeInst$vmethods	soot_baf_internal_BSpecialInvokeInst;
};

// Vtype
struct _jc_soot_baf_internal_BSpecialInvokeInst$vtype {
	_jc_type			type;
	_jc_soot_baf_internal_BSpecialInvokeInst$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_baf_internal_BSpecialInvokeInst$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_baf_internal_BSpecialInvokeInst$refs {
    _jc_soot_baf_internal_BSpecialInvokeInst$sub_refs	soot_baf_internal_BSpecialInvokeInst;
    _jc_soot_baf_internal_AbstractInvokeInst$sub_refs	soot_baf_internal_AbstractInvokeInst;
    _jc_soot_baf_internal_AbstractInst$sub_refs	soot_baf_internal_AbstractInst;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_baf_internal_BSpecialInvokeInst$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_baf_internal_BSpecialInvokeInst$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_baf_internal_AbstractInst$sub_nonrefs	soot_baf_internal_AbstractInst;
    _jc_soot_baf_internal_AbstractInvokeInst$sub_nonrefs	soot_baf_internal_AbstractInvokeInst;
    _jc_soot_baf_internal_BSpecialInvokeInst$sub_nonrefs	soot_baf_internal_BSpecialInvokeInst;
};

// Object instance structure
struct _jc_soot_baf_internal_BSpecialInvokeInst$object {
	_jc_soot_baf_internal_BSpecialInvokeInst$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_baf_internal_BSpecialInvokeInst$vtype	*vtype;
	_jc_soot_baf_internal_BSpecialInvokeInst$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_baf_internal_BSpecialInvokeInst$vtype _jc_soot_baf_internal_BSpecialInvokeInst$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_baf_internal_BSpecialInvokeInst, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_baf_internal_BSpecialInvokeInst$class_object;

#endif	/* _JC_soot_baf_internal_BSpecialInvokeInst_H_ */
